@@ -68,6 +68,9 @@ class _Trochoid(ABC):
         self.thetas = self._validate_theta(thetas, theta_start, theta_stop, theta_step)
         self.origin = origin
 
+        if self.R <= 0 or self.r <= 0 or self.d <= 0:
+            raise ValueError("Negative and/or zero input parameters were passed. Please only pass positive values")
+
         self.x = np.array([self._calculate_x(theta) for theta in self.thetas])
         self.y = np.array([self._calculate_y(theta) for theta in self.thetas])
         self.x += self.origin[0]
